changeset 3525:df6b35fcb8c9

Rename: broken_for_distcc -> force_sequential_build
author Han-Wen Nienhuys <hanwen@lilypond.org>
date Sun, 27 May 2007 16:27:40 -0300
parents 75a789acb1fc
children 81744a4edccd
files gub/gubb.py gub/specs/libiconv.py gub/specs/lilypond.py gub/specs/pic.py gub/specs/pjproject.py gub/specs/tcltk.py gub/specs/xerces-c.py gub/targetpackage.py
diffstat 8 files changed, 11 insertions(+), 13 deletions(-) [+]
line wrap: on
line diff
--- a/gub/gubb.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/gubb.py	Sun May 27 16:27:40 2007 -0300
@@ -127,7 +127,7 @@
         # FIMXE: '' always depends on runtime?
         return {'': [], 'devel': [], 'doc': [], 'runtime': []}
   
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         """Set to true if package can't handle make -jX """
         return False
     
@@ -267,7 +267,7 @@
             ## distcc during configure.
             c = 'DISTCC_HOSTS="%s" %s' % (self.settings.native_distcc_hosts, c)
             c = 'PATH="%(native_distcc_bindir)s:$PATH" ' + c
-        elif (not self.broken_for_distcc()
+        elif (not self.force_sequential_build()
               and self.settings.cpu_count_str != '1'):
             job_spec += ' -j%s ' % self.settings.cpu_count_str
 
--- a/gub/specs/libiconv.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/libiconv.py	Sun May 27 16:27:40 2007 -0300
@@ -6,7 +6,7 @@
         targetpackage.TargetBuildSpec.__init__ (self, settings)
         self.with_template (version='1.11', mirror=mirrors.gnu)
     
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         return True
     
     def get_build_dependencies (self):
--- a/gub/specs/lilypond.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/lilypond.py	Sun May 27 16:27:40 2007 -0300
@@ -55,7 +55,7 @@
     def get_subpackage_names (self):
         return ['']
     
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         ## mf/ is broken
         return True
 
--- a/gub/specs/pic.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/pic.py	Sun May 27 16:27:40 2007 -0300
@@ -16,7 +16,7 @@
     def get_subpackage_names (self):
         return ['']
     
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         ## upnpAllegro is broken
         return True
 
--- a/gub/specs/tcltk.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/tcltk.py	Sun May 27 16:27:40 2007 -0300
@@ -11,7 +11,7 @@
             version='8.4.14')
     def license_file (self):
         return "%(srcdir)s/tcl/license.terms"
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         return True
     def configure (self):
         self.system ('''cd %(srcdir)s/tcl &&  ./unix/configure --prefix=%(install_prefix)s
--- a/gub/specs/xerces-c.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/xerces-c.py	Sun May 27 16:27:40 2007 -0300
@@ -19,9 +19,7 @@
             'CXXFLAGS': ' -DPROJ_XMLPARSER -DPROJ_XMLUTIL -DPROJ_PARSERS -DPROJ_SAX4C -DPROJ_SAX2 -DPROJ_DOM -DPROJ_DEPRECATED_DOM -DPROJ_VALIDATORS -DXML_USE_NATIVE_TRANSCODER -DXML_USE_INMEM_MESSAGELOADER -DXML_USE_PTHREADS -DXML_USE_NETACCESSOR_SOCKET ',
             }
         gubb.change_target_dict (self, self.compile_dict)
-        # FIXME: broken for make -j2, why does broken_for_distcc not handle?
-        self.settings.cpu_count_str = '1'
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         return True
     def patch (self):
         self.shadow_tree ('%(srcdir)s', '%(builddir)s')
--- a/gub/targetpackage.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/targetpackage.py	Sun May 27 16:27:40 2007 -0300
@@ -75,7 +75,7 @@
     def compile_command (self):
         c = gubb.BuildSpec.compile_command (self)
         if (self.settings.cross_distcc_hosts
-            and not self.broken_for_distcc ()
+            and not self.force_sequential_build ()
             and re.search (r'\bmake\b', c)):
             
             jobs = '-j%d ' % (2*len (self.settings.cross_distcc_hosts.split (' ')))
@@ -85,7 +85,7 @@
             ## distcc during configure.
             c = 'DISTCC_HOSTS="%s" %s' % (self.settings.cross_distcc_hosts , c)
             c = 'PATH="%(cross_distcc_bindir)s:$PATH" ' + c
-        elif (not self.broken_for_distcc ()
+        elif (not self.force_sequential_build ()
               and self.settings.cpu_count_str):
             c = re.sub (r'\bmake\b', 'make -j%s '% self.settings.cpu_count_str, c)
--- a/gub/specs/pjproject.py	Sun May 27 16:26:03 2007 -0300
+++ b/gub/specs/pjproject.py	Sun May 27 16:27:40 2007 -0300
@@ -8,9 +8,9 @@
                                           url='http://www.pjsip.org/release/0.5.10.1/pjproject-0.5.10.1.tar.gz',
                                           version='0.5.10.1',
                                           strip_components=True))
         # FIXME: broken for make -j2, why does broken_for_distcc not handle?
         self.settings.cpu_count_str = '1'
-    def broken_for_distcc (self):
+    def force_sequential_build (self):
         return True
     def patch (self):
         self.system ('cd %(srcdir)s && patch -p0 < %(patchdir)s/pjproject-install.patch')
@@ -8,9 +8,9 @@
                                           version='0.5.10.1',
                                           strip_components=True))
-        # FIXME: broken for make -j2, why does broken_for_distcc not handle?
+        # FIXME: broken for make -j2, why does force_sequential_build not handle?
         self.settings.cpu_count_str = '1'